brotli (brotli v0.3.3)
View SourceSummary
Functions
Compress data in one step.
Compress data in one step with custom options.
Maximal possible size of the compressed data of size Size.
Return version of the underlying Brotli C implementation.
Functions
Compress data in one step.
-spec encode(Data :: iodata(), Opts :: brotli_encoder:options()) -> {ok, iodata()} | error.
Compress data in one step with custom options.
-spec max_compressed_size(non_neg_integer()) -> non_neg_integer().
Maximal possible size of the compressed data of size Size.
Return version of the underlying Brotli C implementation.
This is not version of the Erlang library.